==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskSummaryFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskSummaryFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluent<A>{
  public ConsoleQuickStartTaskSummaryFluentImpl() {
  }
  public ConsoleQuickStartTaskSummaryFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary instance) {
    this.withFailed(instance.getFailed()); 
    this.withSuccess(instance.getSuccess()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String failed;
  private java.lang.String success;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFailed() {
    return this.failed;
  }
  public A withFailed(java.lang.String failed) {
    this.failed=failed; return (A) this;
  }
  public java.lang.Boolean hasFailed() {
    return this.failed != null;
  }
  
  /**
   * Method is deprecated. use withFailed instead.
   */
  @java.lang.Deprecated
  public A withNewFailed(java.lang.String arg0) {
    return (A)withFailed(new String(arg0));
  }
  public java.lang.String getSuccess() {
    return this.success;
  }
  public A withSuccess(java.lang.String success) {
    this.success=success; return (A) this;
  }
  public java.lang.Boolean hasSuccess() {
    return this.success != null;
  }
  
  /**
   * Method is deprecated. use withSuccess instead.
   */
  @java.lang.Deprecated
  public A withNewSuccess(java.lang.String arg0) {
    return (A)withSuccess(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskSummaryFluentImpl that = (ConsoleQuickStartTaskSummaryFluentImpl) o;
    if (failed != null ? !failed.equals(that.failed) :that.failed != null) return false;
    if (success != null ? !success.equals(that.success) :that.success != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  success,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskSummaryFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskSummaryFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummaryFluent<A>{
  public ConsoleQuickStartTaskSummaryFluentImpl() {
  }
  public ConsoleQuickStartTaskSummaryFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskSummary instance) {
    this.withFailed(instance.getFailed()); 
    this.withSuccess(instance.getSuccess()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String failed;
  private java.lang.String success;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFailed() {
    return this.failed;
  }
  public A withFailed(java.lang.String failed) {
    this.failed=failed; return (A) this;
  }
  public java.lang.Boolean hasFailed() {
    return this.failed != null;
  }
  
  /**
   * Method is deprecated. use withFailed instead.
   */
  @java.lang.Deprecated
  public A withNewFailed(java.lang.String arg0) {
    return (A)withFailed(new String(arg0));
  }
  public java.lang.String getSuccess() {
    return this.success;
  }
  public A withSuccess(java.lang.String success) {
    this.success=success; return (A) this;
  }
  public java.lang.Boolean hasSuccess() {
    return this.success != null;
  }
  
  /**
   * Method is deprecated. use withSuccess instead.
   */
  @java.lang.Deprecated
  public A withNewSuccess(java.lang.String arg0) {
    return (A)withSuccess(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskSummaryFluentImpl that = (ConsoleQuickStartTaskSummaryFluentImpl) o;
    if (failed != null ? !failed.equals(that.failed) :that.failed != null) return false;
    if (success != null ? !success.equals(that.success) :that.success != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  success,  additionalProperties,  super.hashCode());
  }
  
}
